// Copyright 2013 Pervasive Displays, Inc.
// Copyright 2013 Embedded Artists AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at:
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
// express or implied.  See the License for the specific language
// governing permissions and limitations under the License.

#ifndef __EPD_H__
#define __EPD_H__

#include "bsp.h"

//TODO
#define PROGMEM /*const*/

// if more SRAM available (8 kBytes)
#define EPD_ENABLE_EXTRA_SRAM 1

//typedef enum {
//	LOW=0,
//	HIGH=1
//} EPD_pinstate;

typedef enum {
  EPD_1_44,        // 128 x 96
  EPD_2_0,         // 200 x 96
  EPD_2_7          // 264 x 176
} EPD_size;

typedef enum {           // Image pixel -> Display pixel
  EPD_compensate,  // B -> W, W -> B (Current Image)
  EPD_white,       // B -> N, W -> W (Current Image)
  EPD_inverse,     // B -> N, W -> B (New Image)
  EPD_normal       // B -> B, W -> W (New Image)
} EPD_stage;

typedef struct
{
  EPD_size size;
  uint16_t stage_time;
  uint16_t factored_stage_time;
  uint16_t lines_per_display;
  uint16_t dots_per_line;
  uint16_t bytes_per_line;
  uint16_t bytes_per_scan;
  PROGMEM const uint8_t *gate_source;
  uint16_t gate_source_length;
  PROGMEM const uint8_t *channel_select;
  uint16_t channel_select_length;
  uint8_t filler;
} COG_Parameters_t;


void EPD_init(EPD_size size);
void EPD_begin(void);
void EPD_end(void);

// set temperature
void EPD_setFactor(int16_t temperature);

// clear display (anything -> white)
void EPD_clear(void);

// assuming a clear (white) screen output an image (PROGMEM data)
void EPD_image(PROGMEM const uint8_t *image);

// change from old image to new image (PROGMEM data)
void EPD_image_progmem(PROGMEM const uint8_t *old_image, PROGMEM const uint8_t *new_image);

#if defined(EPD_ENABLE_EXTRA_SRAM)
// change from old image to new image (SRAM version)
void EPD_image_sram(const uint8_t *old_image, const uint8_t *new_image);
#endif


#endif  //__EPD_H__


